@@ -1,5 +1,6 @@
 /*
  *   Copyright 2009 Andrew Stromme <astromme@chatonka.com>
+ *   Copyright 2012 Jeremy Whiting <jpwhiting@kde.org>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -20,20 +21,14 @@
 #ifndef RTM_SESSION_H
 #define RTM_SESSION_H
 
+#include <QHash>
 #include <QObject>
-#include <QDateTime>
 
 #include "rtm.h"
-#include "task.h"
 
+#ifndef QTONLY
 #include <Solid/Networking>
-
-namespace RTM {
-  class Request;
-  class SessionPrivate;
-  class TasksReader;
-}
-
+#endif
 
 /** @file
  * This file is part of librtm. It defines
@@ -43,11 +38,16 @@ namespace RTM {
  * @author Andrew Stromme <astromme@chatonka.com>
  */
 
-/** 
+/**
  * Provides a set of classes for interacting with the Remember The Milk online todo management service
  */
 namespace RTM {
 
+class Request;
+class SessionPrivate;
+class Task;
+class TasksReader;
+
 /**
  * @brief The Session class provides a high level interface to a Remember The Milk session
  *
@@ -60,7 +60,7 @@ Q_OBJECT
     Session(QString apiKey, QString sharedSecret, RTM::Permissions permissions, QString token = QString(), QObject *parent = 0);
     virtual ~Session();
 
-    QString getAuthUrl() const;
+    Q_INVOKABLE QString getAuthUrl() const;
     bool authenticated() const;
 
     RTM::Request* request(const QString& method);
@@ -82,19 +82,23 @@ Q_OBJECT
     void refreshListsFromServer();
     QHash<RTM::TaskId,RTM::Task*> cachedTasks() const;
     QHash<RTM::ListId,RTM::List*> cachedLists() const;
+    /**
+     * Get all known tags.
+     */
+    QStringList allTags() const;
 
     RTM::Task* taskFromId(RTM::TaskId id) const;
     RTM::Task* newBlankTask(RTM::TaskId id) const;
-    
+
     RTM::List* listFromId(RTM::ListId id) const;
     RTM::List* newBlankList(RTM::ListId id) const;
 
   public Q_SLOTS:
-    void showLoginWindow();
     void setToken(const QString &token);
     void handleResponse();
     void continueAuthForToken();
     void addTask(const QString &task, RTM::ListId listId);
+    void addList(const QString &list, const QString &filter = QString());
     void tokenCheckReply(RTM::Request*);
     void handleValidToken(bool);
     void timelineReply(RTM::Request*);
@@ -103,13 +107,13 @@ Q_OBJECT
   Q_SIGNALS:
     void tokenReceived(const QString& token);
     void tokenCheck(bool success);
-    
+
     void settingsUpdated();
     void timelineCreated(RTM::Timeline timeline);
 
     void taskChanged(RTM::Task* task);
     void listChanged(RTM::List* list);
-  
+
     void tasksChanged();
     void listsChanged();
 
@@ -122,7 +126,9 @@ Q_OBJECT
     Q_PRIVATE_SLOT(d, void listUpdate(RTM::Request* reply))
     Q_PRIVATE_SLOT(d, void smartListReply(RTM::Request* reply))
     Q_PRIVATE_SLOT(d, void settingsReply(RTM::Request* reply))
+#ifndef QTONLY
     Q_PRIVATE_SLOT(d, void networkStatusChanged(Solid::Networking::Status))
+#endif
     Q_PRIVATE_SLOT(d, void offlineError())
     Q_PRIVATE_SLOT(d, void retestOfflineStatus())
 };
